@@ -72,6 +72,23 @@ int gnutls_pem_base64_encode_alloc( const char* header, const gnutls_datum *data
 int gnutls_pem_base64_decode_alloc( const char* header, const gnutls_datum *b64_data, 
 	gnutls_datum* result);
 
+/* key_usage will be an OR of the following values:
+ */
+#define GNUTLS_KEY_DIGITAL_SIGNATURE            128	/* when the key is to be
+							 * used for signing.
+							 */
+#define GNUTLS_KEY_NON_REPUDIATION              64
+#define GNUTLS_KEY_KEY_ENCIPHERMENT             32	/* when the key is to be
+							 * used for encryption.
+							 */
+#define GNUTLS_KEY_DATA_ENCIPHERMENT            16
+#define GNUTLS_KEY_KEY_AGREEMENT                8
+#define GNUTLS_KEY_KEY_CERT_SIGN                4
+#define GNUTLS_KEY_CRL_SIGN                     2
+#define GNUTLS_KEY_ENCIPHER_ONLY                1
+#define GNUTLS_KEY_DECIPHER_ONLY                32768
+
+
 # endif /* LIBGNUTLS_VERSION */
 
 #endif /* GNUTLS_UI_H */
