@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2002 Andrew McDonald
  * Portions Copyright 2003 Nikos Mavroyanopoulos
+ * Copyright (C) 2004 Free Software Foundation
  *
  * This file is part of GNUTLS.
  *
@@ -25,80 +26,8 @@
 #include <x509.h>
 #include <dn.h>
 #include <common.h>
-#include <gnutls/compat8.h>
 #include <rfc2818.h>
-
-/*-
-  * gnutls_x509_check_certificates_hostname - This function compares the given hostname with the hostname in the certificate
-  * @cert: should contain a DER encoded certificate
-  * @hostname: A null terminated string that contains a DNS name
-  *
-  * This function will check if the given certificate's subject matches
-  * the given hostname. This is a basic implementation of the matching 
-  * described in RFC2818 (HTTPS), which takes into account wildcards.
-  *
-  * Returns non zero on success, and zero on failure.
-  *
-  -*/
-int gnutls_x509_check_certificates_hostname(const gnutls_datum * cert,
-                                const char *hostname)
-{
-   char dnsname[MAX_CN];
-   int dnsnamesize;
-   int found_dnsname = 0;
-   int ret = 0;
-   gnutls_x509_dn dn;
-   int i = 0;
-
-   /* try matching against:
-    *  1) a DNS name as an alternative name (subjectAltName) extension
-    *     in the certificate
-    *  2) the common name (CN) in the certificate
-    *
-    *  either of these may be of the form: *.domain.tld
-    *
-    *  only try (2) if there is no subjectAltName extension of
-    *  type dNSName
-    */
-
-   /* Check through all included subjectAltName extensions, comparing
-    * against all those of type dNSName.
-    */
-   for (i = 0; !(ret < 0); i++) {
-
-      dnsnamesize = MAX_CN;
-      ret =
-          gnutls_x509_extract_certificate_subject_alt_name(cert, i,
-                                                           dnsname,
-                                                           &dnsnamesize);
-
-      if (ret == GNUTLS_SAN_DNSNAME) {
-         found_dnsname = 1;
-         if (_gnutls_hostname_compare(dnsname, hostname)) {
-            return 1;
-         }
-      }
-
-   }
-
-   if (!found_dnsname) {
-      /* not got the necessary extension, use CN instead 
-       */
-      if (gnutls_x509_extract_certificate_dn(cert, &dn) != 0) {
-         /* got an error, can't find a name 
-          */
-         return 0;
-      }
-
-      if (_gnutls_hostname_compare(dn.common_name, hostname)) {
-         return 1;
-      }
-   }
-
-   /* not found a matching name
-    */
-   return 0;
-}
+#include <gnutls_errors.h>
 
 /* compare hostname against certificate, taking account of wildcards
  * return 1 on success or 0 on error 
@@ -144,7 +73,8 @@ int _gnutls_hostname_compare(const char *certname, const char *hostname)
   *
   * This function will check if the given certificate's subject matches
   * the given hostname. This is a basic implementation of the matching 
-  * described in RFC2818 (HTTPS), which takes into account wildcards.
+  * described in RFC2818 (HTTPS), which takes into account wildcards,
+  * and the subject alternative name PKIX extension.
   *
   * Returns non zero on success, and zero on failure.
   *
@@ -183,7 +113,7 @@ int gnutls_x509_crt_check_hostname(gnutls_x509_crt cert,
       if (ret == GNUTLS_SAN_DNSNAME) {
          found_dnsname = 1;
          if (_gnutls_hostname_compare(dnsname, hostname)) {
-            return 1;
+            return GNUTLS_E_NAME_DOES_NOT_MATCH;
          }
       }
 
@@ -194,14 +124,14 @@ int gnutls_x509_crt_check_hostname(gnutls_x509_crt cert,
        */
       dnsnamesize = sizeof(dnsname);
       if (gnutls_x509_crt_get_dn_by_oid(cert, OID_X520_COMMON_NAME, 0,
-      		0, dnsname, &dnsnamesize) != 0) {
+      		0, dnsname, &dnsnamesize) < 0) {
          /* got an error, can't find a name 
           */
-         return 0;
+         return GNUTLS_E_NAME_DOES_NOT_MATCH;
       }
 
       if (_gnutls_hostname_compare(dnsname, hostname)) {
-         return 1;
+         return GNUTLS_E_NAME_DOES_NOT_MATCH;
       }
    }
 
