@@ -1,3 +1,24 @@
+/*
+ * Copyright (C) 2000,2001,2002,2003 Nikos Mavroyanopoulos
+ * Copyright (C) 2004 Free Software Foundation
+ *
+ * This file is part of GNUTLS.
+ *
+ * GNUTLS is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * GNUTLS is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ */
+
 #include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -62,16 +83,14 @@ void print_x509_info(gnutls_session session, const char* hostname)
 	printf(" - Got a certificate list of %d certificates.\n\n",
 	       cert_list_size);
 
-	for (j = 0; j < (uint)cert_list_size; j++) {
+	for (j = 0; j < (unsigned int)cert_list_size; j++) {
 
 		gnutls_x509_crt_init(&crt);
 		ret =
 		    gnutls_x509_crt_import(crt, &cert_list[j],
 					   GNUTLS_X509_FMT_DER);
 		if (ret < 0) {
-			const char* str = gnutls_strerror(ret);
-			if (str == NULL) str = str_unknown;
-			fprintf(stderr, "Decoding error: %s\n", str);
+			fprintf(stderr, "Decoding error: %s\n", gnutls_strerror(ret));
 			return;
 		}
 
@@ -110,10 +129,8 @@ void print_x509_info(gnutls_session session, const char* hostname)
 
 			ret = gnutls_x509_crt_to_xml( crt, &xml_data, 0);
 			if (ret < 0) {
-				const char* str = gnutls_strerror(ret);
-				if (str == NULL) str = str_unknown;
 				fprintf(stderr, "XML encoding error: %s\n",
-					str);
+					gnutls_strerror(ret));
 				return;
 			}
 			
@@ -147,9 +164,7 @@ void print_x509_info(gnutls_session session, const char* hostname)
 			digest_size = sizeof(digest);
 			if ((ret=gnutls_x509_crt_get_fingerprint(crt, GNUTLS_DIG_MD5, digest, &digest_size))
 			    < 0) {
-				const char* str = gnutls_strerror(ret);
-				if (str == NULL) str = str_unknown;
-			    	fprintf(stderr, "Error in fingerprint calculation: %s\n", str);
+			    	fprintf(stderr, "Error in fingerprint calculation: %s\n", gnutls_strerror(ret));
 			} else {
 				print = printable;
 				for (i = 0; i < digest_size; i++) {
@@ -225,9 +240,7 @@ void print_openpgp_info(gnutls_session session, const char* hostname)
 		ret =
 		    gnutls_openpgp_key_import(crt, &cert_list[0], GNUTLS_OPENPGP_FMT_RAW);
 		if (ret < 0) {
-			const char* str = gnutls_strerror(ret);
-			if (str == NULL) str = str_unknown;
-			fprintf(stderr, "Decoding error: %s\n", str);
+			fprintf(stderr, "Decoding error: %s\n", gnutls_strerror(ret));
 			return;
 		}
 
@@ -262,10 +275,8 @@ void print_openpgp_info(gnutls_session session, const char* hostname)
 
 			ret = gnutls_openpgp_key_to_xml( crt, &xml_data, 0);
 			if (ret < 0) {
-				const char* str = gnutls_strerror(ret);
-				if (str == NULL) str = str_unknown;
 				fprintf(stderr, "XML encoding error: %s\n",
-					str);
+					gnutls_strerror(ret));
 				return;
 			}
 			
@@ -503,26 +514,26 @@ void print_list(void)
 	printf(", ANON-DH\n");
 
 	printf("Compression methods:");
-	printf(" ZLIB");
+	printf(" DEFLATE");
 	printf(", LZO");
 	printf(", NULL\n");
 }
 
 void print_license(void)
 {
-	fprintf(stdout,
-		"\nCopyright (C) 2001-2003 Nikos Mavroyanopoulos\n"
-		"This program is free software; you can redistribute it and/or modify \n"
-		"it under the terms of the GNU General Public License as published by \n"
-		"the Free Software Foundation; either version 2 of the License, or \n"
-		"(at your option) any later version. \n" "\n"
-		"This program is distributed in the hope that it will be useful, \n"
-		"but WITHOUT ANY WARRANTY; without even the implied warranty of \n"
-		"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the \n"
-		"GNU General Public License for more details. \n" "\n"
-		"You should have received a copy of the GNU General Public License \n"
-		"along with this program; if not, write to the Free Software \n"
-		"Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.\n\n");
+fputs(	"\nCopyright (C) 2004 Free Software Foundation\n"
+	"This program is free software; you can redistribute it and/or modify \n"
+	"it under the terms of the GNU General Public License as published by \n"
+	"the Free Software Foundation; either version 2 of the License, or \n"
+	"(at your option) any later version. \n" "\n"
+	"This program is distributed in the hope that it will be useful, \n"
+	"but WITHOUT ANY WARRANTY; without even the implied warranty of \n"
+	"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the \n"
+	"GNU General Public License for more details. \n" "\n"
+	"You should have received a copy of the GNU General Public License \n"
+	"along with this program; if not, write to the Free Software \n"
+	"Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.\n\n",
+	stdout);
 }
 
 void parse_protocols(char **protocols, int protocols_size,
@@ -534,8 +545,9 @@ void parse_protocols(char **protocols, int protocols_size,
 		for (j = i = 0; i < protocols_size; i++) {
 			if (strncasecmp(protocols[i], "SSL", 3) == 0)
 				protocol_priority[j++] = GNUTLS_SSL3;
-			if (strncasecmp(protocols[i], "TLS", 3) == 0)
+			else if (strncasecmp(protocols[i], "TLS", 3) == 0)
 				protocol_priority[j++] = GNUTLS_TLS1;
+			else fprintf(stderr, "Unknown protocol: '%s'\n", protocols[i]);
 		}
 		protocol_priority[j] = 0;
 	}
@@ -550,17 +562,18 @@ void parse_ciphers(char **ciphers, int nciphers, int *cipher_priority)
 			if (strncasecmp(ciphers[i], "AES", 3) == 0)
 				cipher_priority[j++] =
 				    GNUTLS_CIPHER_AES_128_CBC;
-			if (strncasecmp(ciphers[i], "3DE", 3) == 0)
+			else if (strncasecmp(ciphers[i], "3DE", 3) == 0)
 				cipher_priority[j++] =
 				    GNUTLS_CIPHER_3DES_CBC;
-			if (strcasecmp(ciphers[i], "ARCFOUR-40") == 0)
+			else if (strcasecmp(ciphers[i], "ARCFOUR-40") == 0)
 				cipher_priority[j++] =
 				    GNUTLS_CIPHER_ARCFOUR_40;
-			if (strcasecmp(ciphers[i], "ARCFOUR") == 0)
+			else if (strcasecmp(ciphers[i], "ARCFOUR") == 0)
 				cipher_priority[j++] =
 				    GNUTLS_CIPHER_ARCFOUR_128;
-			if (strncasecmp(ciphers[i], "NUL", 3) == 0)
+			else if (strncasecmp(ciphers[i], "NUL", 3) == 0)
 				cipher_priority[j++] = GNUTLS_CIPHER_NULL;
+			else fprintf(stderr, "Unknown cipher: '%s'\n", ciphers[i]);
 		}
 		cipher_priority[j] = 0;
 	}
@@ -573,10 +586,11 @@ void parse_macs(char **macs, int nmacs, int *mac_priority)
 		for (j = i = 0; i < nmacs; i++) {
 			if (strncasecmp(macs[i], "MD5", 3) == 0)
 				mac_priority[j++] = GNUTLS_MAC_MD5;
-			if (strncasecmp(macs[i], "RMD", 3) == 0)
+			else if (strncasecmp(macs[i], "RMD", 3) == 0)
 				mac_priority[j++] = GNUTLS_MAC_RMD160;
-			if (strncasecmp(macs[i], "SHA", 3) == 0)
+			else if (strncasecmp(macs[i], "SHA", 3) == 0)
 				mac_priority[j++] = GNUTLS_MAC_SHA;
+			else fprintf(stderr, "Unknown MAC: '%s'\n", macs[i]);
 		}
 		mac_priority[j] = 0;
 	}
@@ -590,8 +604,9 @@ void parse_ctypes(char **ctype, int nctype, int *cert_type_priority)
 			if (strncasecmp(ctype[i], "OPE", 3) == 0)
 				cert_type_priority[j++] =
 				    GNUTLS_CRT_OPENPGP;
-			if (strncasecmp(ctype[i], "X", 1) == 0)
+			else if (strncasecmp(ctype[i], "X", 1) == 0)
 				cert_type_priority[j++] = GNUTLS_CRT_X509;
+			else fprintf(stderr, "Unknown certificate type: '%s'\n", ctype[i]);
 		}
 		cert_type_priority[j] = 0;
 	}
@@ -604,20 +619,21 @@ void parse_kx(char **kx, int nkx, int *kx_priority)
 		for (j = i = 0; i < nkx; i++) {
 			if (strcasecmp(kx[i], "SRP") == 0)
 				kx_priority[j++] = GNUTLS_KX_SRP;
-			if (strcasecmp(kx[i], "SRP-RSA") == 0)
+			else if (strcasecmp(kx[i], "SRP-RSA") == 0)
 				kx_priority[j++] = GNUTLS_KX_SRP_RSA;
-			if (strcasecmp(kx[i], "SRP-DSS") == 0)
+			else if (strcasecmp(kx[i], "SRP-DSS") == 0)
 				kx_priority[j++] = GNUTLS_KX_SRP_DSS;
-			if (strcasecmp(kx[i], "RSA") == 0)
+			else if (strcasecmp(kx[i], "RSA") == 0)
 				kx_priority[j++] = GNUTLS_KX_RSA;
-			if (strcasecmp(kx[i], "RSA-EXPORT") == 0)
+			else if (strcasecmp(kx[i], "RSA-EXPORT") == 0)
 				kx_priority[j++] = GNUTLS_KX_RSA_EXPORT;
-			if (strncasecmp(kx[i], "DHE-RSA", 7) == 0)
+			else if (strncasecmp(kx[i], "DHE-RSA", 7) == 0)
 				kx_priority[j++] = GNUTLS_KX_DHE_RSA;
-			if (strncasecmp(kx[i], "DHE-DSS", 7) == 0)
+			else if (strncasecmp(kx[i], "DHE-DSS", 7) == 0)
 				kx_priority[j++] = GNUTLS_KX_DHE_DSS;
-			if (strncasecmp(kx[i], "ANON", 4) == 0)
+			else if (strncasecmp(kx[i], "ANON", 4) == 0)
 				kx_priority[j++] = GNUTLS_KX_ANON_DH;
+			else fprintf(stderr, "Unknown key exchange: '%s'\n", kx[i]);
 		}
 		kx_priority[j] = 0;
 	}
@@ -630,10 +646,13 @@ void parse_comp(char **comp, int ncomp, int *comp_priority)
 		for (j = i = 0; i < ncomp; i++) {
 			if (strncasecmp(comp[i], "NUL", 3) == 0)
 				comp_priority[j++] = GNUTLS_COMP_NULL;
-			if (strncasecmp(comp[i], "ZLI", 3) == 0)
-				comp_priority[j++] = GNUTLS_COMP_ZLIB;
-			if (strncasecmp(comp[i], "LZO", 3) == 0)
+			else if (strncasecmp(comp[i], "ZLI", 3) == 0)
+				comp_priority[j++] = GNUTLS_COMP_DEFLATE;
+			else if (strncasecmp(comp[i], "DEF", 3) == 0)
+				comp_priority[j++] = GNUTLS_COMP_DEFLATE;
+			else if (strncasecmp(comp[i], "LZO", 3) == 0)
 				comp_priority[j++] = GNUTLS_COMP_LZO;
+			else fprintf(stderr, "Unknown compression: '%s'\n", comp[i]);
 		}
 		comp_priority[j] = 0;
 	}
@@ -657,11 +676,11 @@ char* ret;
 
 	ret = inet_ntoa( *((struct in_addr*)src));
 	
-	if (strlen(ret) > cnt) {
+	if (ret == NULL || strlen(ret) > cnt) {
 		return NULL;
 	}
 	strcpy( dst, ret);
-	
+
 	return dst;
 }
 #endif
